%define srcname docutils

%bcond_with check

Name:		python-%{srcname}
Summary:	Python Documentation Utilities
# WARNING: make sure before upgrading to 0.18.* or more that this
#          does not break too many packages.
Version:	0.21.2
Release:	%mkrel 3
URL:		https://docutils.sourceforge.net/
License:	Public Domain and BSD and Python and GPLv3+
Group:		Development/Python
# Sometimes we need snapshots.  Instructions below:
# svn co -r 7747 https://docutils.svn.sourceforge.net/svnroot/docutils/trunk/docutils
# cd docutils
# python setup.py sdist
# The tarball is in dist/docutils-VERSION.tar.gz
#Source0:	%%{srcname}-%%{version}.tar.gz
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:	pyproject-rpm-macros
BuildRequires:	emacs

%description
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

%package -n python3-%{srcname}
Summary:	System for processing plaintext documentation for python
Group:		Development/Python
Recommends:	python3dist(pillow)
%{?python_provide:%python_provide python3-%{srcname}}
Provides:	rst2html = %{version}-%{release}
Provides:	rst2man = %{version}-%{release}

%description -n python3-%{srcname}
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

%prep
%setup -q -n %{srcname}-%{version}


# Remove shebang from library files
for file in docutils/utils/{code_analyzer.py,punctuation_chars.py,error_reporting.py} docutils/utils/math/{latex2mathml.py,math2html.py} docutils/writers/xetex/__init__.py; do
sed -i -e '/#! *\/usr\/bin\/.*/{1D}' $file
done

iconv -f ISO88592 -t UTF8 tools/editors/emacs/IDEAS.rst > tmp
mv tmp tools/editors/emacs/IDEAS.rst

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files docutils

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python3_sitelib}/test

%if 0
for file in %{buildroot}%_bindir/*.py; do
  mv $file %{buildroot}%_bindir/`basename $file .py`
done
%endif

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf

# Make emacs mode available:
emacs -batch -f batch-byte-compile tools/editors/emacs/rst.el
%__install -d -m 755 %{buildroot}%{_datadir}/emacs/site-lisp
%__install -D -m 644 tools/editors/emacs/rst.el* %{buildroot}%{_datadir}/emacs/site-lisp
%__rm -rf tools/editors/emacs

cat > ./rst.el << EOF
(autoload 'rst-mode "rst" "reStructuredText mode" t)
(add-to-list 'auto-mode-alist '("\\.rst$" . rst-mode))
EOF
emacs -batch -f batch-byte-compile rst.el
%__install -d -m 755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
%__install -m 644 rst.el* %{buildroot}%{_sysconfdir}/emacs/site-start.d/

%check
%if %{with check}
%{__python3} test/alltests.py
rm docs/user/rst/images/biohazard.swf
%endif

%files -n python3-%{srcname} -f %{pyproject_files}
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt
%doc THANKS.txt licenses docs tools/editors
%{_bindir}/docutils
%{_bindir}/rst2html
%{_bindir}/rst2html4
%{_bindir}/rst2html5
%{_bindir}/rst2latex
%{_bindir}/rst2man
%{_bindir}/rst2odt
%{_bindir}/rst2pseudoxml
%{_bindir}/rst2s5
%{_bindir}/rst2xetex
%{_bindir}/rst2xml

%{_datadir}/emacs/site-lisp/*
%{_sysconfdir}/emacs/site-start.d/*


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.21.2-3.mga10
+ Revision: 2236173
- Mageia 10 Mass Rebuild

* Fri Feb 21 2025 wally <wally> 0.21.2-2.mga10
+ Revision: 2150477
- rebuild for python3.13

* Thu Dec 19 2024 papoteur <papoteur> 0.21.2-1.mga10
+ Revision: 2126218
- new version 0.21.2

* Wed Apr 17 2024 kekepower <kekepower> 0.21.1-1.mga10
+ Revision: 2058313
- Update to version 0.21.1

* Thu Dec 07 2023 wally <wally> 0.20.1-2.mga10
+ Revision: 2014807
- rebuild for py3.12

* Tue Oct 17 2023 papoteur <papoteur> 0.20.1-1.mga10
+ Revision: 1998060
- new 0.20.1

* Sun Feb 19 2023 wally <wally> 0.19-1.mga9
+ Revision: 1944063
- new version 0.19
+ neoclust <neoclust>
- New version

* Tue Mar 29 2022 umeabot <umeabot> 0.17.1-3.mga9
+ Revision: 1831656
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 joequant <joequant> 0.17.1-2.mga9
+ Revision: 1782176
- update to python 3.10

* Sun Feb 20 2022 tv <tv> 0.17.1-1.mga9
+ Revision: 1781680
- Downgrade to 0.17.1 (0.18 is incompatible with way too many packages)

* Sun Feb 13 2022 tmb <tmb> 0.18.1-2.mga9
+ Revision: 1774056
- rebuild for python 3.10

* Sun Feb 06 2022 wally <wally> 0.18.1-1.mga9
+ Revision: 1771949
- new version 0.18.1
- rebuild for python3.10

* Sun Mar 14 2021 wally <wally> 0.16-2.mga9
+ Revision: 1702542
- rebuild for python 3.9

* Fri Apr 10 2020 daviddavid <daviddavid> 0.16-1.mga8
+ Revision: 1566025
- new version: 0.16

* Sun Feb 16 2020 umeabot <umeabot> 0.15.2-3.mga8
+ Revision: 1530707
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 0.15.2-2.mga8
+ Revision: 1437298
- another rebuild for python3.8
- drop python2 support
- rebuild for python3.8

* Wed Aug 21 2019 wally <wally> 0.15.2-1.mga8
+ Revision: 1430712
- new version 0.15.2

* Sat Jan 05 2019 wally <wally> 0.14-5.mga7
+ Revision: 1349573
- rebuild for python3

* Thu Jan 03 2019 alexl <alexl> 0.14-4.mga7
+ Revision: 1348761
- rebuild

* Tue Jan 01 2019 wally <wally> 0.14-3.mga7
+ Revision: 1347976
- make python3 default
- provide rst2html and rst2man in python3 pkg

* Thu Nov 01 2018 daviddavid <daviddavid> 0.14-2.mga7
+ Revision: 1327261
- fix recommended pkgs
- use new python macros

* Thu Nov 01 2018 kekepower <kekepower> 0.14-1.mga7
+ Revision: 1327196
- Update to version 0.14
- Rename python-docutils to python2-docutils
- Use python_provides

* Thu Sep 20 2018 umeabot <umeabot> 0.12-2.svn7747.7.mga7
+ Revision: 1288784
- Mageia 7 Mass Rebuild

* Fri Aug 04 2017 tv <tv> 0.12-2.svn7747.6.mga7
+ Revision: 1134526
- rebuild for new python

* Fri Feb 19 2016 umeabot <umeabot> 0.12-2.svn7747.5.mga6
+ Revision: 970445
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 tv <tv> 0.12-2.svn7747.4.mga6
+ Revision: 886754
- rebuild for python 3.5

* Sat Sep 26 2015 blino <blino> 0.12-1.svn7747.4.mga6
+ Revision: 883868
- drop unneeded python-pytools buildrequires
  because of build/dep loop docutils -> pytools -> decorator -> nose -> sphinx -> docutils

* Wed Oct 15 2014 umeabot <umeabot> 0.12-1.svn7747.3.mga5
+ Revision: 749999
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.12-1.svn7747.2.mga5
+ Revision: 728372
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Jun 18 2014 philippem <philippem> 0.12-0.svn7747.1.mga5
+ Revision: 637980
- Update to svn snapshot for Python 3.4 support

* Sat May 31 2014 pterjan <pterjan> 0.11-5.mga5
+ Revision: 628615
- Rebuild for new Python

* Mon Mar 10 2014 philippem <philippem> 0.11-4.mga5
+ Revision: 601883
- disable test on BS (they are ok on local iurt build)

* Tue Oct 22 2013 umeabot <umeabot> 0.11-3.mga4
+ Revision: 543374
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.11-2.mga4
+ Revision: 498435
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 0.11-1.mga4
+ Revision: 471627
- Update to 0.11

* Sun Jan 13 2013 umeabot <umeabot> 0.10-0.svn7502.2.mga3
+ Revision: 378760
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 philippem <philippem> 0.10-0.svn7502.1.mga3
+ Revision: 339979
- Update to new upstream

* Tue Sep 04 2012 philippem <philippem> 0.9.1-1.mga3
+ Revision: 288134
- New upstream release 0.9.1

* Sat Oct 22 2011 philippem <philippem> 0.8.1-1.mga2
+ Revision: 157386
- new version 0.8.1

* Mon Jan 31 2011 dmorgan <dmorgan> 0.7-4.mga1
+ Revision: 45389
- Rebuild because of missing provides

* Mon Jan 17 2011 misc <misc> 0.7-3.mga1
+ Revision: 21017
- rebuilt for new python

* Thu Jan 13 2011 ahmad <ahmad> 0.7-2.mga1
+ Revision: 8311
- imported package python-docutils


* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 0.7-2mdv2011.0
+ Revision: 590062
- rebuild for python 2.7

* Sat Aug 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7-1mdv2011.0
+ Revision: 567230
- update to 0.7

* Mon Jan 04 2010 Lev Givon <lev@mandriva.org> 0.6-1mdv2010.1
+ Revision: 486092
- Update to 0.6.

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 0.5-2mdv2009.1
+ Revision: 319373
- rebuild for new python

* Thu Aug 07 2008 Lev Givon <lev@mandriva.org> 0.5-1mdv2009.0
+ Revision: 265323
- Update to 0.5.
  Make emacs mode automatically available.

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 0.4-6mdv2009.0
+ Revision: 242390
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun May 27 2007 Bogdano Arendartchuk <bogdano@mandriva.com> 0.4-4mdv2008.0
+ Revision: 31678
- added requires to python, as it uses pprint

* Fri May 25 2007 Bogdano Arendartchuk <bogdano@mandriva.com> 0.4-3mdv2008.0
+ Revision: 31138
- removed .py suffix of files installed in %%_bindir, as it's done
  by other distros
- force the installation of roman.py


* Wed Dec 13 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.4-2mdv2007.0
+ Revision: 96084
- Fix File section
- Rebuild for new python
- Import python-docutils

* Fri Mar 03 2006 Austin Acton <austin@mandriva.org> 0.4-1mdk
- New release 0.4

* Thu Jan 12 2006 Michael Scherer <misc@mandriva.org> 0.3.9-2mdk
- Use new python macro
- use mkrel

* Wed Nov 23 2005 Austin Acton <austin@mandriva.org> 0.3.9-1mdk
- 0.3.9

* Mon Mar 14 2005 Michael Scherer <misc@mandrake.org> 0.3.7-1mdk
- New release 0.3.7
- noarch

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.3-2mdk
- Rebuild for new python

